import request from '@/utils/request';
function getCurrentTimestamp() {
  return new Date().getTime();
}

//我负责的页面获取项目
export function GetProject(page, pageSize, token) {
  return request({
    url: '/project/my/get',
    method: 'get',
    params: { page, pageSize },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//新增项目
export function AddProject(data, token) {
  return request({
    url: '/project/add',
    method: 'post',
    data,
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//删除项目
export function DeleteProject(id, token) {
  return request({
    url: '/project/delete',
    method: 'delete',
    params:{ id },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//编辑项目
export function EditProject(projectId, data, token) {
  return request({
    url: '/project/edit/' + projectId,
    method: 'put',
    data,
    headers: {
      'Authorization': 'Bearer ' + token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//根据项目名字模糊查询
export function GetProjectByName(name, token) {
  return request({
    url: '/project/get/name',
    method: 'get',
    params: { name },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//根据项目id查询子系统
export function GetChildSysById(projectId, token) {
  return request({
    url: "/module/get?projectId=" + projectId ,
    method: 'get',
    params: { projectId },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//根据项目名和子系统名查询子模块
export function  GetChildSysByName(projectName, childName, token) {
  return request({
    url: '/project/module/get/name',
    method: 'get',
    params: { projectName, childName },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//新增子系统
export function AddChildSystem(data, token) {
  return request({
    url: '/project/child/add',
    method: 'post',
    data,
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//新增子模块
export function AddChildModule(data, token) {
  return request({
    url: '/project/module/add',
    method: 'post',
    data,
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}

//删除子模块
export function DeleteChildModule(id, token) {
  return request({
    url: '/project/module/delete',
    method: 'delete',
    params:{ id },
    headers: {
      'Authorization':'Bearer '+ token,
      'content-type': 'application/json;charset=utf-8',
      'Timestamp': getCurrentTimestamp()
    }
  });
}
